aboutsummaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/private/LanguageModel/LanguageModelManager.php5
-rw-r--r--lib/public/LanguageModel/ILanguageModelManager.php3
2 files changed, 5 insertions, 3 deletions
diff --git a/lib/private/LanguageModel/LanguageModelManager.php b/lib/private/LanguageModel/LanguageModelManager.php
index 340116e7d71..4a29e8d8b18 100644
--- a/lib/private/LanguageModel/LanguageModelManager.php
+++ b/lib/private/LanguageModel/LanguageModelManager.php
@@ -8,6 +8,7 @@ use OC\LanguageModel\Db\TaskMapper;
use OCP\AppFramework\Db\DoesNotExistException;
use OCP\AppFramework\Db\MultipleObjectsReturnedException;
use OCP\BackgroundJob\IJobList;
+use OCP\Common\Exception\NotFoundException;
use OCP\DB\Exception;
use OCP\IServerContainer;
use OCP\LanguageModel\AbstractLanguageModelTask;
@@ -152,14 +153,14 @@ class LanguageModelManager implements ILanguageModelManager {
* @param int $id The id of the task
* @return ILanguageModelTask
* @throws RuntimeException If the query failed
* @throws \ValueError If the task could not be found
*/
public function getTask(int $id): ILanguageModelTask {
try {
$taskEntity = $this->taskMapper->find($id);
return AbstractLanguageModelTask::fromTaskEntity($taskEntity);
} catch (DoesNotExistException $e) {
- throw new \ValueError('Could not find task with the provided id');
+ throw new NotFoundException('Could not find task with the provided id');
} catch (MultipleObjectsReturnedException $e) {
throw new RuntimeException('Could not uniquely identify task with given id');
} catch (Exception $e) {
@@ -152,14 +153,14 @@ class LanguageModelManager implements ILanguageModelManager {
* @return ILanguageModelTask
* @throws RuntimeException If the query failed
- * @throws \ValueError If the task could not be found
+ * @throws NotFoundException If the task could not be found
*/
public function getTask(int $id): ILanguageModelTask {
diff --git a/lib/public/LanguageModel/ILanguageModelManager.php b/lib/public/LanguageModel/ILanguageModelManager.php
index 80546149a62..4c28ca86d72 100644
--- a/lib/public/LanguageModel/ILanguageModelManager.php
+++ b/lib/public/LanguageModel/ILanguageModelManager.php
@@ -26,6 +26,7 @@ declare(strict_types=1);
namespace OCP\LanguageModel;
+use OCP\Common\Exception\NotFoundException;
use OCP\PreConditionNotMetException;
use RuntimeException;
@@ -70,7 +71,7 @@ interface ILanguageModelManager {
* @param int $id The id of the task
* @return ILanguageModelTask
* @throws RuntimeException If the query failed
* @throws \ValueError If the task could not be found
* @since 28.0.0
*/
public function getTask(int $id): ILanguageModelTask;
@@ -70,7 +71,7 @@ interface ILanguageModelManager {
* @return ILanguageModelTask
* @throws RuntimeException If the query failed
- * @throws \ValueError If the task could not be found
+ * @throws NotFoundException If the task could not be found
* @since 28.0.0
*/